@@ -13,10 +13,19 @@
    (eval . (put 'lambda* 'scheme-indent-function 1))
    (eval . (put 'substitute* 'scheme-indent-function 1))
    (eval . (put 'with-directory-excursion 'scheme-indent-function 1))
-   (eval . (put 'package 'scheme-indent-function 1))
+   (eval . (put 'package 'scheme-indent-function 0))
+   (eval . (put 'origin 'scheme-indent-function 0))
+   (eval . (put 'manifest-entry 'scheme-indent-function 0))
+   (eval . (put 'manifest-pattern 'scheme-indent-function 0))
    (eval . (put 'substitute-keyword-arguments 'scheme-indent-function 1))
    (eval . (put 'with-error-handling 'scheme-indent-function 0))
-   (eval . (put 'with-mutex 'scheme-indent-function 1))))
+   (eval . (put 'with-mutex 'scheme-indent-function 1))
+
+   (eval . (put 'syntax-parameterize 'scheme-indent-function 1))
+   (eval . (put 'with-monad 'scheme-indent-function 1))
+   (eval . (put 'mlet* 'scheme-indent-function 2))
+   (eval . (put 'mlet 'scheme-indent-function 2))
+   (eval . (put 'run-with-store 'scheme-indent-function 1))))
  (emacs-lisp-mode . ((indent-tabs-mode . nil)))
  (texinfo-mode    . ((indent-tabs-mode . nil)
                      (fill-column . 72))))
