@@ -25,20 +25,20 @@
 (define-public lightning
   (package
     (name "lightning")
-    (version "2.0.0")
+    (version "2.0.2")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/lightning/lightning-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "0m0hc9aqw72wsg2sq2hx8zwhfvz814rfr7rz9qcyn3n4qv2kc5z4"))))
+               "100ya7dx12403gimif7p2q7ahd8vxqrxpxqzqr1zqci825nb0b43"))))
     (build-system gnu-build-system)
     (synopsis "Library for generating assembly code at runtime")
     (description
-     "GNU lightning is a library that generates assembly language code at
-run-time; it is very fast, making it ideal for Just-In-Time compilers, and it
-abstracts over the target CPU, as it exposes to the clients a standardized
-RISC instruction set inspired by the MIPS and SPARC chips.")
+     "GNU Lightning is a library that generates assembly language code at
+run-time.  Thus, it is useful in creating Just-In-Time compilers.  It
+abstracts over the target CPU by exposing a standardized RISC instruction set
+to the clients.")
     (home-page "http://www.gnu.org/software/lightning/")
     (license gpl3+)))
