@@ -28,14 +28,14 @@
 (define-public texinfo
   (package
     (name "texinfo")
-    (version "5.1")
+    (version "5.2")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/texinfo/texinfo-"
                                  version ".tar.xz"))
              (sha256
               (base32
-               "0864v5i488x3mb3v5p6nhy2kw0mqkzpa3b0453iibj81zlpq078q"))))
+               "1njfwh2z34r2c4r0iqa7v24wmjzvsfyz4vplzry8ln3479lfywal"))))
     (build-system gnu-build-system)
     (inputs `(("ncurses" ,ncurses)
               ("xz" ,xz)
@@ -43,17 +43,10 @@
     (home-page "http://www.gnu.org/software/texinfo/")
     (synopsis "The GNU documentation format")
     (description
-     "Texinfo is the official documentation format of the GNU project.
-It was invented by Richard Stallman and Bob Chassell many years
-ago, loosely based on Brian Reid's Scribe and other formatting
-languages of the time.  It is used by many non-GNU projects as
-well.
-
-Texinfo uses a single source file to produce output in a number
-of formats, both online and printed (dvi, html, info, pdf, xml,
-etc.).  This means that instead of writing different documents
-for online information and another for a printed manual, you
-need write only one document.  And when the work is revised, you
-need revise only that one document.  The Texinfo system is
-well-integrated with GNU Emacs.")
+     "Texinfo is the official documentation format of the GNU project.  It
+uses a single source file using explicit commands to produce a final document
+in any of several supported output formats, such as HTML or PDF.  This
+package includes both the tools necessary to produce Info documents from
+their source and the command-line Info reader.  The emphasis of the language
+is on expressing the content semantically, avoiding physical markup commands.")
     (license gpl3+)))
