@@ -59,20 +59,6 @@
     (home-page "http://www.gnu.org/software/zile/")
     (synopsis "Zile is lossy Emacs, a lightweight Emacs clone")
     (description
-     "GNU Zile, which is a lightweight Emacs clone.  Zile is short
-for Zile Is Lossy Emacs.  Zile has been written to be as
-similar as possible to Emacs; every Emacs user should feel at
-home.
-
-Zile has all of Emacs's basic editing features: it is 8-bit
-clean (though it currently lacks Unicode support), and the
-number of editing buffers and windows is only limited by
-available memory and screen space respectively.  Registers,
-minibuffer completion and auto fill are available.  Function
-and variable names are identical with Emacs's (except those
-containing the word \"emacs\", which instead contain the word
-\"zile\"!).
-
-However, all of this is packed into a program which typically
-compiles to about 130Kb.")
+     "GNU Zile is a lightweight Emacs clone.  It usage is similar to the
+default Emacs configuration, but it carries a much lighter feature set.")
     (license gpl3+)))
