@@ -20,12 +20,12 @@
   #:use-module (guix store)
   #:use-module (guix records)
   #:use-module (guix packages)
+  #:use-module (guix monads)
   #:use-module ((gnu packages system)
                 #:select (shadow))
+  #:use-module (gnu packages bash)
   #:use-module (srfi srfi-1)
-  #:use-module (srfi srfi-26)
   #:use-module (ice-9 match)
-  #:use-module (ice-9 format)
   #:export (user-account
             user-account?
             user-account-name
@@ -35,6 +35,7 @@
             user-account-comment
             user-account-home-directory
             user-account-shell
+            user-account-inputs
 
             user-group
             user-group?
@@ -62,7 +63,9 @@
   (gid            user-account-gid)
   (comment        user-account-comment (default ""))
   (home-directory user-account-home-directory)
-  (shell          user-account-shell (default "/bin/sh")))
+  (shell          user-account-shell              ; monadic value
+                  (default (package-file bash "bin/bash")))
+  (inputs         user-account-inputs (default `(("bash" ,bash)))))
 
 (define-record-type* <user-group>
   user-group make-user-group
@@ -72,7 +75,7 @@
   (id             user-group-id)
   (members        user-group-members (default '())))
 
-(define (group-file store groups)
+(define (group-file groups)
   "Return a /etc/group file for GROUPS, a list of <user-group> objects."
   (define contents
     (let loop ((groups groups)
@@ -87,55 +90,36 @@
         (()
          (string-join (reverse result) "\n" 'suffix)))))
 
-  (add-text-to-store store "group" contents))
+  (text-file "group" contents))
 
-(define* (passwd-file store accounts #:key shadow?)
+(define* (passwd-file accounts #:key shadow?)
   "Return a password file for ACCOUNTS, a list of <user-account> objects.  If
 SHADOW? is true, then it is a /etc/shadow file, otherwise it is a /etc/passwd
 file."
   ;; XXX: The resulting file is world-readable, so beware when SHADOW? is #t!
-  (define contents
-    (let loop ((accounts accounts)
-               (result   '()))
-      (match accounts
-        ((($ <user-account> name pass uid gid comment home-dir shell)
-          rest ...)
-         (loop rest
-               (cons (if shadow?
-                         (string-append name
-                                        ":"       ; XXX: use (crypt PASS …)?
-                                        ":::::::")
-                         (string-append name
-                                        ":" "x"
-                                        ":" (number->string uid)
-                                        ":" (number->string gid)
-                                        ":" comment ":" home-dir ":" shell))
-                     result)))
-        (()
-         (string-join (reverse result) "\n" 'suffix)))))
+  (define (contents)
+    (with-monad %store-monad
+      (let loop ((accounts accounts)
+                 (result   '()))
+        (match accounts
+          ((($ <user-account> name pass uid gid comment home-dir mshell)
+            rest ...)
+           (mlet %store-monad ((shell mshell))
+             (loop rest
+                   (cons (if shadow?
+                             (string-append name
+                                            ":"    ; XXX: use (crypt PASS …)?
+                                            ":::::::")
+                             (string-append name
+                                            ":" "x"
+                                            ":" (number->string uid)
+                                            ":" (number->string gid)
+                                            ":" comment ":" home-dir ":" shell))
+                         result))))
+          (()
+           (return (string-join (reverse result) "\n" 'suffix)))))))
 
-  (add-text-to-store store (if shadow? "shadow" "passwd")
-                     contents '()))
-
-(define* (guix-build-accounts store count #:key
-                              (first-uid 30001)
-                              (gid 30000)
-                              (shadow shadow))
-  "Return a list of COUNT user accounts for Guix build users, with UIDs
-starting at FIRST-UID, and under GID."
-  (let* ((gid*     gid)
-         (no-login (string-append (package-output store shadow) "/sbin/nologin")))
-    (unfold (cut > <> count)
-            (lambda (n)
-              (user-account
-               (name (format #f "guixbuilder~2,'0d" n))
-               (password "!")
-               (uid (+ first-uid n -1))
-               (gid gid*)
-               (comment (format #f "Guix Build User ~2d" n))
-               (home-directory "/var/empty")
-               (shell no-login)))
-            1+
-            1)))
+  (mlet %store-monad ((contents (contents)))
+    (text-file (if shadow? "shadow" "passwd") contents)))
 
 ;;; shadow.scm ends here
