@@ -47,9 +47,8 @@
                      (outputs '("out")) (configure-flags ''())
                      (search-paths '())
                      (make-flags ''())
-                     (patches ''()) (patch-flags ''("--batch" "-p1"))
                      (cmake (default-cmake))
-                     (out-of-source? #f)
+                     (out-of-source? #t)
                      (tests? #t)
                      (test-target "test")
                      (parallel-build? #t) (parallel-tests? #f)
@@ -65,7 +64,6 @@
                                          (guix build gnu-build-system)
                                          (guix build utils)))
                      (modules '((guix build cmake-build-system)
-                                (guix build gnu-build-system)
                                 (guix build utils))))
   "Build SOURCE using CMAKE, and with INPUTS. This assumes that SOURCE
 provides a 'CMakeLists.txt' file as its build system."
@@ -81,8 +79,6 @@ provides a 'CMakeLists.txt' file as its build system."
                     #:search-paths ',(map search-path-specification->sexp
                                           (append search-paths
                                                   (standard-search-paths)))
-                    #:patches ,patches
-                    #:patch-flags ,patch-flags
                     #:phases ,phases
                     #:configure-flags ,configure-flags
                     #:make-flags ,make-flags
@@ -108,8 +104,9 @@ provides a 'CMakeLists.txt' file as its build system."
          (package-derivation store guile system)))))
 
   (let ((cmake (package-derivation store cmake system)))
-    (build-expression->derivation store name system
-                                  builder
+    (build-expression->derivation store name builder
+                                  #:system system
+                                  #:inputs
                                   `(,@(if source
                                           `(("source" ,source))
                                           '())
