@@ -1,5 +1,5 @@
 /* GNU Guix --- Functional package management for GNU
-   Copyright (C) 2012  Ludovic Courtès <ludo@gnu.org>
+   Copyright (C) 2012, 2013  Ludovic Courtès <ludo@gnu.org>
 
    This file is part of GNU Guix.
 
@@ -24,7 +24,7 @@
 extern "C" {
 
 void
-guix_hash_init (struct guix_hash_context *ctx, gcry_md_algo_t algo)
+guix_hash_init (struct guix_hash_context *ctx, int algo)
 {
   gcry_error_t err;
 
@@ -40,7 +40,7 @@ guix_hash_update (struct guix_hash_context *ctx, const void *buffer, size_t len)
 
 void
 guix_hash_final (void *resbuf, struct guix_hash_context *ctx,
-		 gcry_md_algo_t algo)
+		 int algo)
 {
   memcpy (resbuf, gcry_md_read (ctx->md_handle, algo),
 	  gcry_md_get_algo_dlen (algo));
